==> akarixb-v0.6.tar.gz: akarixb-v0.6/src/messagehandler.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MESSAGEHANDLER_H
#define MESSAGEHANDLER_H

#include <QObject>

#include <QDebug>


#include <QXmppClient.h>
#include <QXmppMucManager.h>
#include <QXmppMessage.h>


#include "globalobject.h"
#include "variableparser.h"


class MessageHandler : public QObject
{
    Q_OBJECT

public:
    explicit MessageHandler(GlobalObject *globalObject, QObject *parent = 0);
    ~MessageHandler();

    void processMessage(QXmppMessage message);


signals:


public slots:


private:
    QXmppClient *m_xmppClient;
    QXmppMucManager *m_mucManager;

    GlobalObject *m_globalObject;
    VariableParser *m_variableParser;
};

#endif // MESSAGEHANDLER_H

==> akarixb-v0.8.tar.gz: akarixb-v0.8/src/messagehandler.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MESSAGEHANDLER_H
#define MESSAGEHANDLER_H

#include <QObject>

#include <QDebug>


#include <QXmppClient.h>
#include <QXmppMucManager.h>
#include <QXmppMessage.h>


#include "globalobject.h"
#include "variableparser.h"


class MessageHandler : public QObject
{
    Q_OBJECT

public:
    explicit MessageHandler(GlobalObject *globalObject,
                            QObject *parent = nullptr);
    ~MessageHandler();

    void processMessage(QXmppMessage message);


signals:


public slots:


private:
    QXmppClient *m_xmppClient;
    QXmppMucManager *m_mucManager;

    GlobalObject *m_globalObject;
    VariableParser *m_variableParser;
};

#endif // MESSAGEHANDLER_H
